@@ -149,6 +149,8 @@ class CardListView(gtk.TreeView, object):
     # We allow access via these properties (for plugins)
     mainwindow = property(fget=lambda self: self._oMainWin,
             doc="The parent window used for dialogs, etc.")
+    searchdialog = property(fget=lambda self: self._oSearchDialog,
+            doc="The search dialog.")
     # pylint: enable-msg=W0212
 
 
